SignalHandler

Enum SignalHandler 

pub enum SignalHandler {
    Default,
    Ignore,
    Hook(SignalHook),
    NoReturnHook(NoReturnSignalHook),
}
Available on Windows and crate feature signals only.
A signal handling method.

Variants



Default

Use the default behavior specified by the C standard.



Ignore

Ignore the signal whenever it is received.



Hook(SignalHook)

Call a function whenever the signal is received. The function can return, execution will continue.



NoReturnHook(NoReturnSignalHook)

Call a function whenever the signal is received. The function must not return.

Implementations

Source

impl SignalHandler

pub const fn is_default(self) -> bool

Returns true for the Default variant, false otherwise.

pub const fn is_ignore(self) -> bool

Returns true for the Ignore variant, false otherwise.

pub const fn is_hook(self) -> bool

Returns true for the Hook and NoReturnHook variants, false otherwise.

pub unsafe fn from_fn(function: fn()) -> Self

Creates a handler which calls the specified function.

Safety

The function must not call any C functions which are not considered signal-safe. See the module-level section on signal-safe C functions for more.

pub unsafe fn from_fn_noreturn(function: fn() -> !) -> Self

Creates a handler which calls the specified function and is known to never return.

Safety

The function must not call any C functions which are not considered signal-safe. See the module-level section on signal-safe C functions for more.